@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: UTF-8 -*
 
 # Copyright (c) 2009, Giampaolo Rodola'. All rights reserved.
 # Use of this source code is governed by a BSD-style license that can be
@@ -15,8 +16,10 @@ import sys
 import time
 import traceback
 
-from test_psutil import WINDOWS, get_test_subprocess, reap_children, unittest
+from test_psutil import APPVEYOR, WINDOWS
+from test_psutil import get_test_subprocess, reap_children, unittest
 
+import mock
 try:
     import wmi
 except ImportError:
@@ -192,20 +195,16 @@ class WindowsSpecificTestCase(unittest.TestCase):
     #                                   time.localtime(p.create_time()))
     #
 
+    # Note: this test is not very reliable
     @unittest.skipIf(wmi is None, "wmi module is not installed")
+    @unittest.skipIf(APPVEYOR, "test not relieable on appveyor")
     def test_pids(self):
         # Note: this test might fail if the OS is starting/killing
         # other processes in the meantime
         w = wmi.WMI().Win32_Process()
-        wmi_pids = [x.ProcessId for x in w]
-        wmi_pids.sort()
-        psutil_pids = psutil.pids()
-        psutil_pids.sort()
-        if wmi_pids != psutil_pids:
-            difference = \
-                filter(lambda x: x not in wmi_pids, psutil_pids) + \
-                filter(lambda x: x not in psutil_pids, wmi_pids)
-            self.fail("difference: " + str(difference))
+        wmi_pids = set([x.ProcessId for x in w])
+        psutil_pids = set(psutil.pids())
+        self.assertEqual(wmi_pids, psutil_pids)
 
     @unittest.skipIf(wmi is None, "wmi module is not installed")
     def test_disks(self):
@@ -283,9 +282,41 @@ class WindowsSpecificTestCase(unittest.TestCase):
         if failures:
             self.fail('\n' + '\n'.join(failures))
 
+    def test_name_always_available(self):
+        # On Windows name() is never supposed to raise AccessDenied,
+        # see https://github.com/giampaolo/psutil/issues/627
+        for p in psutil.process_iter():
+            try:
+                p.name()
+            except psutil.NoSuchProcess:
+                pass
+
+    @unittest.skipUnless(sys.version_info >= (2, 7),
+                         "CTRL_* signals not supported")
+    def test_ctrl_signals(self):
+        p = psutil.Process(get_test_subprocess().pid)
+        p.send_signal(signal.CTRL_C_EVENT)
+        p.send_signal(signal.CTRL_BREAK_EVENT)
+        p.kill()
+        p.wait()
+        self.assertRaises(psutil.NoSuchProcess,
+                          p.send_signal, signal.CTRL_C_EVENT)
+        self.assertRaises(psutil.NoSuchProcess,
+                          p.send_signal, signal.CTRL_BREAK_EVENT)
+
 
 @unittest.skipUnless(WINDOWS, "not a Windows system")
 class TestDualProcessImplementation(unittest.TestCase):
+    """
+    Certain APIs on Windows have 2 internal implementations, one
+    based on documented Windows APIs, another one based
+    NtQuerySystemInformation() which gets called as fallback in
+    case the first fails because of limited permission error.
+    Here we test that the two methods return the exact same value,
+    see:
+    https://github.com/giampaolo/psutil/issues/304
+    """
+
     fun_names = [
         # function name, tolerance
         ('proc_cpu_times', 0.2),
@@ -296,13 +327,6 @@ class TestDualProcessImplementation(unittest.TestCase):
     ]
 
     def test_compare_values(self):
-        # Certain APIs on Windows have 2 internal implementations, one
-        # based on documented Windows APIs, another one based
-        # NtQuerySystemInformation() which gets called as fallback in
-        # case the first fails because of limited permission error.
-        # Here we test that the two methods return the exact same value,
-        # see:
-        # https://github.com/giampaolo/psutil/issues/304
         def assert_ge_0(obj):
             if isinstance(obj, tuple):
                 for value in obj:
@@ -374,6 +398,55 @@ class TestDualProcessImplementation(unittest.TestCase):
         if failures:
             self.fail('\n\n'.join(failures))
 
+    # ---
+    # same tests as above but mimicks the AccessDenied failure of
+    # the first (fast) method failing with AD.
+    # TODO: currently does not take tolerance into account.
+
+    def test_name(self):
+        name = psutil.Process().name()
+        with mock.patch("psutil._psplatform.cext.proc_exe",
+                        side_effect=psutil.AccessDenied(os.getpid())) as fun:
+            psutil.Process().name() == name
+            assert fun.called
+
+    def test_memory_info(self):
+        mem = psutil.Process().memory_info()
+        with mock.patch("psutil._psplatform.cext.proc_memory_info",
+                        side_effect=OSError(errno.EPERM, "msg")) as fun:
+            psutil.Process().memory_info() == mem
+            assert fun.called
+
+    def test_create_time(self):
+        ctime = psutil.Process().create_time()
+        with mock.patch("psutil._psplatform.cext.proc_create_time",
+                        side_effect=OSError(errno.EPERM, "msg")) as fun:
+            psutil.Process().create_time() == ctime
+            assert fun.called
+
+    def test_cpu_times(self):
+        cpu_times = psutil.Process().cpu_times()
+        with mock.patch("psutil._psplatform.cext.proc_cpu_times",
+                        side_effect=OSError(errno.EPERM, "msg")) as fun:
+            psutil.Process().cpu_times() == cpu_times
+            assert fun.called
+
+    def test_io_counters(self):
+        io_counters = psutil.Process().io_counters()
+        with mock.patch("psutil._psplatform.cext.proc_io_counters",
+                        side_effect=OSError(errno.EPERM, "msg")) as fun:
+            psutil.Process().io_counters() == io_counters
+            assert fun.called
+
+    def test_num_handles(self):
+        io_counters = psutil.Process().io_counters()
+        with mock.patch("psutil._psplatform.cext.proc_io_counters",
+                        side_effect=OSError(errno.EPERM, "msg")) as fun:
+            psutil.Process().io_counters() == io_counters
+            assert fun.called
+
+    # --- other tests
+
     def test_compare_name_exe(self):
         for p in psutil.process_iter():
             try:
@@ -400,6 +473,7 @@ def main():
     result = unittest.TextTestRunner(verbosity=2).run(test_suite)
     return result.wasSuccessful()
 
+
 if __name__ == '__main__':
     if not main():
         sys.exit(1)
